@@ -332,7 +332,6 @@ def calculate_hybrid_lcoe(diesel_price, end_year, start_year, energy_per_hh,
     return sum_costs / sum_el_gen, investment, total_battery_investment, total_fuel_cost, total_om_cost
 
 
-@numba.njit
 def find_least_cost_option(configuration, temp, ghi, hour_numbers, load_curve, inv_eff, n_dis, n_chg, dod_max,
                            energy_per_hh, diesel_price, end_year, start_year, pv_cost, charge_controller, pv_om,
                            diesel_cost, diesel_om, inverter_life, inverter_cost, diesel_life, pv_life, battery_cost,
@@ -411,128 +410,3 @@ def calc_load_curve(tier, energy_per_hh):
         load_curve = tier5_load_curve * 365
 
     return np.array(load_curve) * energy_per_hh / 365
-
-
-def pv_diesel_hybrid(
-        energy_per_hh,  # kWh/household/year as defined
-        ghi,
-        ghi_curve,
-        temp,
-        tier,
-        start_year,
-        end_year,
-        diesel_price,
-        max_cycles=950,  # cycles to failure at dod_max
-        dod_max=0.9,  # maximum depth of discharge of battery
-        diesel_cost=565,  # diesel generator capital cost, USD/kW rated power  # ToDo check
-        pv_no=20,  # number of PV panel sizes simulated
-        diesel_no=20,  # number of diesel generators simulated
-        discount_rate=0.08,
-        n_chg=0.93,  # charge efficiency of battery
-        n_dis=1,  # discharge efficiency of battery
-        lpsp_max=0.02,  # maximum loss of load allowed over the year, in share of kWh
-        battery_cost=577, #314,  # battery capital capital cost, USD/kWh of storage capacity
-        pv_cost=660, # 810,  # PV panel capital cost, USD/kW peak power
-        pv_life=25,  # PV panel expected lifetime, years
-        diesel_life=10,  # diesel generator expected lifetime, years
-        pv_om=0.015,  # annual OM cost of PV panels
-        diesel_om=0.1,  # annual OM cost of diesel generator
-        inverter_cost=66, # 105,
-        inverter_life=20,
-        inv_eff=0.93, # 0.92  # inverter_efficiency
-        charge_controller=142,
-        battery_sizes=[0.5, 1, 2, 3],
-        diesel_limit=0.5,
-        array_output=False
-):
-
-    ghi = ghi_curve * ghi * 1000 / ghi_curve.sum()
-
-    hour_numbers = np.empty(8760)
-    for i in prange(365):
-        for j in prange(24):
-            hour_numbers[i * 24 + j] = j
-
-    load_curve = calc_load_curve(tier, energy_per_hh)
-
-    # This section creates the range of PV capacities, diesel capacities and battery sizes to be simulated
-    ref = 5 * load_curve[19]
-    pv_caps = []
-    for i in prange(pv_no):
-        pv_caps.append(ref * (i) / pv_no)
-
-    if max(load_curve) < 0.5:
-        diesel_caps = np.array([0.5])
-    else:
-        diesel_caps = np.linspace(0.5, max(load_curve), diesel_no).tolist()
-        # step_size = math.ceil(max(load_curve) * 2 / diesel_no)
-        # steps = math.ceil(max(load_curve) * 2 / step_size) + 1
-        # diesel_caps = np.ones(steps) * step_size
-        # for i in prange(steps):
-        #     diesel_caps[i] = diesel_caps[i] * i * 0.5
-
-    battery_sizes = np.array(battery_sizes) * energy_per_hh / 365  # [0.5 * energy_per_hh / 365, energy_per_hh / 365, 2 * energy_per_hh / 365]
-
-    min_diesel_share = 0
-    min_pv_capacity = 0
-    min_diesel_capacity = 0
-    min_lcoe = 99
-    min_investment = 0
-    min_battery_investment = 0
-    min_fuel_cost = 0
-    min_om_cost = 0
-
-    if array_output:
-        lcoe_array = np.zeros(shape=(len(battery_sizes), len(pv_caps), len(diesel_caps)), dtype=float)
-        lpsp_array = np.ones(shape=(len(battery_sizes), len(pv_caps), len(diesel_caps)), dtype=float)
-
-    p=-1
-    b=-1
-    d=-1
-
-    for battery_capacity in battery_sizes:
-        b += 1
-        p = -1
-        for pv_size in pv_caps:
-            p+=1
-            d = -1
-            for diesel_size in diesel_caps:
-                d+=1
-
-                configuration = [pv_size, battery_capacity, diesel_size]
-
-                lcoe, lpsp, diesel_share, investment, battery_investment, fuel_cost, om_cost,\
-                    battery, battery_life, gen_capacity = find_least_cost_option(configuration,
-                                                                              temp, ghi, hour_numbers,
-                                                                              load_curve, inv_eff, n_dis, n_chg,
-                                                                              dod_max, energy_per_hh, diesel_price,
-                                                                              end_year, start_year, pv_cost,
-                                                                              charge_controller, pv_om, diesel_cost,
-                                                                              diesel_om, inverter_life, inverter_cost,
-                                                                              diesel_life, pv_life, battery_cost,
-                                                                              discount_rate, lpsp_max, diesel_limit,
-                                                                              simple=False)
-
-                if array_output & (lcoe < 99):  # ToDo check b, p, d
-                    lcoe_array[b][p][d] = lcoe
-                    lpsp_array[b][p][d] = lpsp
-
-                if (lcoe < min_lcoe) & (lpsp < lpsp_max) & (diesel_share < diesel_limit):
-                    min_battery_investment = battery_investment
-                    min_diesel_share = diesel_share
-                    min_lcoe = lcoe
-                    min_investment = investment
-                    min_pv_capacity = pv_size
-                    min_diesel_capacity = diesel_size
-                    min_battery = battery_capacity # * 365 / energy_per_hh
-                    min_fuel_cost = fuel_cost
-                    min_om_cost = om_cost
-
-    if array_output:
-        lcoe_array[lcoe_array == 0] = np.nan
-        lpsp_array[lpsp_array == 1] = np.nan
-        return min_lcoe, min_investment, min_pv_capacity, min_diesel_capacity, min_battery_investment, 1 - min_diesel_share, len(pv_caps) * len(battery_sizes) * len(diesel_caps), lcoe_array, pv_caps, diesel_caps, lpsp_array #battery_sizes
-        # return min_lcoe, min_investment, min_pv_capacity, min_diesel_capacity, min_battery, 1 - min_diesel_share, len(pv_caps) * len(battery_sizes) * len(diesel_caps), lcoe_array, pv_caps, diesel_caps, battery_sizes
-    else:
-        return min_lcoe, min_investment, min_pv_capacity, min_diesel_capacity, min_battery_investment, 1 - min_diesel_share, len(pv_caps) * len(battery_sizes) * len(diesel_caps), min_fuel_cost, min_om_cost
-        #return min_lcoe, min_investment, min_pv_capacity, min_diesel_capacity, min_battery, 1 - min_diesel_share, len(pv_caps) * len(battery_sizes) * len(diesel_caps)
